==> yast2_3.1.108.orig.tar.gz: yast2-3.1.108/library/commandline/testsuite/tests/command7.rb <==
# encoding: utf-8

# ***************************************************************************
#
# Copyright (c) 2002 - 2012 Novell, Inc.
# All Rights Reserved.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of version 2 of the GNU General Public License as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail,
# you may find current contact information at www.novell.com
#
# ***************************************************************************
# File:	command6.ycp
# Package:	yast2
# Summary:	test command-line parsing for non-strict actions
# Author:	Stanislav Visnovsky <visnov@suse.cz>
#
# $Id$
#
# testedfiles: CommandLine.ycp Testsuite.ycp
module Yast
  class Command7Client < Client
    def main
      Yast.include self, "testsuite.rb"
      Yast.include self, "testsuitedata.rb"

      Yast.import "CommandLine"

      # list is non-strict, so any parameter can be passed to it, but known are checked,
      # so configured is incorrect here
      TEST(lambda { CommandLine.Init(@cmdline, ["list", "eth0", "configured=1"]) }, [], nil)
      TEST(lambda { CommandLine.Command }, [], nil) 

      # EOF

      nil
    end
  end
end

Yast::Command7Client.new.main

==> yast2_3.1.166.orig.tar.gz: yast2-3.1.221/library/commandline/testsuite/tests/command7.rb <==
# encoding: utf-8

# ***************************************************************************
#
# Copyright (c) 2002 - 2012 Novell, Inc.
# All Rights Reserved.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of version 2 of the GNU General Public License as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail,
# you may find current contact information at www.novell.com
#
# ***************************************************************************
# File:	command6.ycp
# Package:	yast2
# Summary:	test command-line parsing for non-strict actions
# Author:	Stanislav Visnovsky <visnov@suse.cz>
#
# $Id$
#
# testedfiles: CommandLine.ycp Testsuite.ycp
module Yast
  class Command7Client < Client
    def main
      Yast.include self, "testsuite.rb"
      Yast.include self, "testsuitedata.rb"

      Yast.import "CommandLine"

      # list is non-strict, so any parameter can be passed to it, but known are checked,
      # so configured is incorrect here
      TEST(->() { CommandLine.Init(@cmdline, ["list", "eth0", "configured=1"]) }, [], nil)
      TEST(->() { CommandLine.Command }, [], nil)

      # EOF

      nil
    end
  end
end

Yast::Command7Client.new.main
